@@ -30,11 +30,9 @@ fn test() {
             < MemoryGroup::new(0, MemoryState::Initialized)
     );
     assert!(
-        MemoryGroup::new(0, MemoryState::Initialized)
-            < MemoryGroup::new(0, MemoryState::Erasing)
+        MemoryGroup::new(0, MemoryState::Initialized) < MemoryGroup::new(0, MemoryState::Erasing)
     );
     assert!(
-        MemoryGroup::new(0, MemoryState::Erasing)
-            < MemoryGroup::new(1, MemoryState::Uninitialized)
+        MemoryGroup::new(0, MemoryState::Erasing) < MemoryGroup::new(1, MemoryState::Uninitialized)
     );
 }
